@@ -847,6 +847,10 @@ typedef int32_t (*cbk_client_t)(xlator_t *this, client_t *client);
 typedef void (*cbk_ictxmerge_t) (xlator_t *this, fd_t *fd,
                                  inode_t *inode, inode_t *linked_inode);
 
+typedef size_t (*cbk_inodectx_size_t)(xlator_t *this, inode_t *inode);
+
+typedef size_t (*cbk_fdctx_size_t)(xlator_t *this, fd_t *fd);
+
 struct xlator_cbks {
         cbk_forget_t             forget;
         cbk_release_t            release;
@@ -855,6 +859,8 @@ struct xlator_cbks {
         cbk_client_t             client_destroy;
         cbk_client_t             client_disconnect;
         cbk_ictxmerge_t          ictxmerge;
+        cbk_inodectx_size_t      ictxsize;
+        cbk_fdctx_size_t         fdctxsize;
 };
 
 typedef int32_t (*dumpop_priv_t) (xlator_t *this);
@@ -944,6 +950,12 @@ struct _xlator {
         /* for the memory pool of 'frame->local' */
         struct mem_pool    *local_pool;
         gf_boolean_t        is_autoloaded;
+
+        /* Saved volfile ID (used for multiplexing) */
+        char               *volfile_id;
+
+        /* Its used as an index to inode_ctx*/
+        uint32_t            xl_id;
 };
 
 typedef struct {
@@ -998,6 +1010,8 @@ void xlator_foreach_depth_first (xlator_t *this,
 				 void *data);
 
 xlator_t *xlator_search_by_name (xlator_t *any, const char *name);
+xlator_t *get_xlator_by_name (xlator_t *this, char *target);
+xlator_t *get_xlator_by_type (xlator_t *this, char *target);
 
 void
 xlator_set_inode_lru_limit (xlator_t *this, void *data);
@@ -1011,6 +1025,7 @@ int loc_copy_overload_parent (loc_t *dst,
 void loc_wipe (loc_t *loc);
 int loc_path (loc_t *loc, const char *bname);
 void loc_gfid (loc_t *loc, uuid_t gfid);
+void loc_pargfid (loc_t *loc, uuid_t pargfid);
 char* loc_gfid_utoa (loc_t *loc);
 gf_boolean_t loc_is_root (loc_t *loc);
 int32_t loc_build_child (loc_t *child, loc_t *parent, char *name);
@@ -1041,4 +1056,9 @@ glusterfs_reachable_leaves(xlator_t *base, dict_t *leaves);
 int
 xlator_subvolume_count (xlator_t *this);
 
+void xlator_init_lock (void);
+void xlator_init_unlock (void);
+int
+copy_opts_to_child (xlator_t *src, xlator_t *dst, char *glob);
+
 #endif /* _XLATOR_H */
